@@ -8,7 +8,8 @@ test_that("basic clhs on a data.frame works", {
   df <- data.frame(
     a = runif(1000), 
     b = rnorm(1000), 
-    c = sample(LETTERS[1:5], size = 1000, replace = TRUE)
+    c = sample(LETTERS[1:5], size = 1000, replace = TRUE),
+    stringsAsFactors = TRUE
   )
   
   res <- clhs(df, size = 5, iter = 100, progress = FALSE)
